@@ -23,6 +23,35 @@ from tencentcloud.asr.v20190614 import models
 class AsrClient(AbstractClient):
     _apiVersion = '2019-06-14'
     _endpoint = 'asr.tencentcloudapi.com'
+    _service = 'asr'
+
+
+    def CloseAsyncRecognitionTask(self, request):
+        """本接口用于关闭语音流异步识别任务。
+
+        :param request: Request instance for CloseAsyncRecognitionTask.
+        :type request: :class:`tencentcloud.asr.v20190614.models.CloseAsyncRecognitionTaskRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.CloseAsyncRecognitionTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CloseAsyncRecognitionTask", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CloseAsyncRecognitionTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
 
 
     def CreateAsrVocab(self, request):
@@ -58,6 +87,39 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateAsyncRecognitionTask(self, request):
+        """本接口用于对语音流进行准实时识别，通过异步回调来返回识别结果。
+        <br>• 支持rtmp、hls、rtsp等流媒体协议，以及各类基于http协议的直播流
+        <br>• 音频流时长无限制，服务会自动拉取音频流数据，若连续10分钟拉不到流数据时，服务会终止识别任务
+        <br>• 服务通过回调的方式来提供识别结果，用户需要提供CallbackUrl
+        <br>• 签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
+        <br>• 默认单账号限制并发数为20路，如您有提高并发限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
+
+        :param request: Request instance for CreateAsyncRecognitionTask.
+        :type request: :class:`tencentcloud.asr.v20190614.models.CreateAsyncRecognitionTaskRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.CreateAsyncRecognitionTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateAsyncRecognitionTask", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateAsyncRecognitionTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateCustomization(self, request):
         """用户使用该接口可以创建自学习模型，以供识别调用
 
@@ -90,7 +152,7 @@ class AsrClient(AbstractClient):
         """本接口服务对时长5小时以内的录音文件进行识别，异步返回识别全部结果。
         <br>• 支持中文普通话、英语、粤语、日语和上海话方言
         <br>• 支持通用、音视频领域
-        <br>• 支持wav、mp3、m4a的音频格式
+        <br>• 支持wav、mp3、m4a、flv、mp4格式
         <br>• 支持语音 URL 和本地语音文件两种请求方式
         <br>• 语音 URL 的音频时长不能长于5小时，文件大小不超过512MB
         <br>• 本地语音文件不能大于5MB
@@ -98,6 +160,7 @@ class AsrClient(AbstractClient):
         <br>• 支持回调或轮询的方式获取结果，结果获取请参考[ 录音文件识别结果查询](https://cloud.tencent.com/document/product/1093/37822)。
         <br>•   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"
         <br>•   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
+        <br>• 默认接口请求频率限制：20次/秒，如您有提高请求频率限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
 
         :param request: Request instance for CreateRecTask.
         :type request: :class:`tencentcloud.asr.v20190614.models.CreateRecTaskRequest`
@@ -180,6 +243,35 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAsyncRecognitionTasks(self, request):
+        """本接口用于查询当前在运行的语音流异步识别任务列表。
+        <br>•   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
+
+        :param request: Request instance for DescribeAsyncRecognitionTasks.
+        :type request: :class:`tencentcloud.asr.v20190614.models.DescribeAsyncRecognitionTasksRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.DescribeAsyncRecognitionTasksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAsyncRecognitionTasks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAsyncRecognitionTasksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTaskStatus(self, request):
         """在调用录音文件识别请求接口后，有回调和轮询两种方式获取识别结果。
         <br>• 当采用回调方式时，识别完成后会将结果通过 POST 请求的形式通知到用户在请求时填写的回调 URL，具体请参见[ 录音识别结果回调 ](https://cloud.tencent.com/document/product/1093/37139#callback)。
